@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.15";
+        "11.0.16.1";
 
     private static final String java_version_date =
-        "2022-04-19";
+        "2022-08-12";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.15+10";
+        "11.0.16.1+1";
 
     private static final String VERSION_NUMBER =
-        "11.0.15";
+        "11.0.16.1";
 
     private static final String VERSION_BUILD =
-        "10";
+        "1";
 
     private static final String VERSION_PRE =
         "";
@@ -75,7 +75,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "Temurin-11.0.15+10";
+        "Temurin-11.0.16.1+1";
 
     private static String VENDOR_URL_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
